Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(772)

Unified Diff: Source/core/css/resolver/StyleResolverState.h

Issue 772803002: Delay construction of StyleResolverState until after style sharing. (Closed) Base URL: https://chromium.googlesource.com/chromium/blink.git@master
Patch Set: Created 6 years ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: Source/core/css/resolver/StyleResolverState.h
diff --git a/Source/core/css/resolver/StyleResolverState.h b/Source/core/css/resolver/StyleResolverState.h
index b0048dc5d402190c5bb6a2cce094ac2e035e2922..39b7d3a17f5798b2953a27ff5414bd4c7cdfe00c 100644
--- a/Source/core/css/resolver/StyleResolverState.h
+++ b/Source/core/css/resolver/StyleResolverState.h
@@ -45,6 +45,7 @@ class StyleResolverState {
STACK_ALLOCATED();
WTF_MAKE_NONCOPYABLE(StyleResolverState);
public:
+ StyleResolverState(Document&, const ElementResolveContext&, RenderStyle* parentStyle);
StyleResolverState(Document&, Element*, RenderStyle* parentStyle = 0);
~StyleResolverState();
@@ -145,8 +146,8 @@ private:
CSSToLengthConversionData m_cssToLengthConversionData;
// m_parentStyle is not always just element->parentNode()->style()
// so we keep it separate from m_elementContext.
RefPtr<RenderStyle> m_parentStyle;
OwnPtrWillBeMember<CSSAnimationUpdate> m_animationUpdate;
@@ -145,8 +146,8 @@ private:
CSSToLengthConversionData m_cssToLengthConversionData;
- // m_parentStyle is not always just element->parentNode()->style()
- // so we keep it separate from m_elementContext.
+ // m_parentStyle is not always just ElementResolveContext::parentStyle,
+ // so we keep it separate.
RefPtr<RenderStyle> m_parentStyle;
OwnPtrWillBeMember<CSSAnimationUpdate> m_animationUpdate;

Powered by Google App Engine
This is Rietveld 408576698